journal_started

Function journal_started 

pub fn journal_started(
    target: &Path,
    op: JournalOp,
    checksum_before: Option<Hash>,
    checksum_after: Hash,
) -> Result<String>
Append a Started entry to the journal for target.

Returns the generated op_id so the caller can correlate the subsequent committed / aborted entry.