pub fn emit_schema_by_name(name: &str, out: impl Write) -> Result<bool>Expand description
Emit the JSON Schema for a subcommand by name, without requiring parsed args.
Returns Ok(true) if the schema was emitted, Ok(false) if the name is unknown.
Errors
Returns an error if writing to the output fails.