Workspace path jail validation. Workspace path jail validation and symlink safety checks.
Functions
- check_
symlink - Return an error if the path is a symbolic link.
- soft_
canonicalize - Resolve
.and..components without touching the filesystem. - validate_
path - Validate that a path is inside the workspace and is not a symlink.
- validate_
path_ with_ symlink - Validate a path with configurable symlink policy.